import pygame

import fonter
import tweening


def render_label(text):
    return fonter.render(text, font_label, 'white', scolor='black')


def render_builtin():
    return fonter.render(*text_font_fg, **shadow_gradient)


def render_tween(ease_function):
    return fonter.render(*text_font_fg, tweener=tweener, ease_function=ease_function, **shadow_gradient)


def render_all():
    global text_font_fg, shadow_gradient
    text_font_fg = 'ABCD', font_tween, pri_color
    shadow_gradient = dict(gcolor=sec_color, scolor='black')
    return [
        render_label('builtin gradient:'),
        render_builtin(),
        render_label('ease_in_quad:'),
        render_tween(tweening.ease_in_quad),
        render_label('ease_out_quad:'),
        render_tween(tweening.ease_out_quad),
        render_label('ease_in_out_quad:'),
        render_tween(tweening.ease_in_out_quad),
        render_label('ease_in_out_expo:'),
        render_tween(tweening.ease_in_out_expo),
        render_label('ease_out_cubic:'),
        render_tween(tweening.ease_out_cubic),
        render_label('ease_in_out_cubic:'),
        render_tween(tweening.ease_in_out_cubic),
        render_label('ease_out_quart:'),
        render_tween(tweening.ease_out_quart),
        render_label('ease_in_quart:'),
        render_tween(tweening.ease_in_quart),
        render_label('ease_in_out_quart:'),
        render_tween(tweening.ease_in_out_quart),
        render_label('ease_out_sine:'),
        render_tween(tweening.ease_out_sine),
        render_label('ease_in_bounce:'),
        render_tween(tweening.ease_in_bounce),
        render_label('ease_out_bounce:'),
        render_tween(tweening.ease_out_bounce),
        render_label('ease_in_out_bounce:'),
        render_tween(tweening.ease_in_out_bounce),
    ]


pygame.init()
screen = pygame.display.set_mode((600, 800))
screen_rect = screen.get_rect()
clock = pygame.time.Clock()
max_fps = 30
dt = 1.0 / max_fps

tweener = tweening.Tweener()

font_label = fonter.load_font('Vera.ttf', 14)
font_tween = fonter.load_font('VeraBd.ttf', 70)
label_height = font_label.get_height() + 2  # shadow is +2
tween_height = font_tween.get_height() + 2  # shadow is +2
item_height = label_height + tween_height

fill_color = pygame.Color('grey30')
pri_color = 'darkblue'
sec_color = 'cornflowerblue'
text_font_fg = 'ABCD', font_tween, pri_color
shadow_gradient = dict(gcolor=sec_color, scolor='black')

surfs = render_all()

while 1:
    clock.tick(max_fps)
    for e in pygame.event.get():
        if e.type == pygame.KEYDOWN:
            if e.key == pygame.K_SPACE:
                pri_color, sec_color = sec_color, pri_color
                surfs = render_all()
            elif e.key == pygame.K_ESCAPE:
                quit()
        elif e.type == pygame.QUIT:
            quit()
    screen.fill(fill_color)
    x = 20
    y = 10
    for surf in surfs:
        surf_height = surf.get_height()
        if surf_height == label_height and y + item_height > screen_rect.h:
            x += screen_rect.centerx
            y = 10
        screen.blit(surf, (x, y))
        y += surf_height
    pygame.display.flip()
